



if not exist %LIBRARY_LIB%\gumbo.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_BIN%\gumbo.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_INC%\gumbo.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
